/*
 * Created on 2005/03/30
 */
package net.asukaze.anxious;

import java.awt.Frame;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;

import javax.swing.SwingUtilities;
import javax.swing.UIManager;

/**
 * @author asukaze
 */
public class Configure {
	private MainForm form;

	public Configure(MainForm form){
		this.form = form;
	}
	
	public static String getConfigureFileName(boolean makedir){
		if(System.getProperty("os.name").startsWith("Windows")){
			File file = new File(System.getProperty("user.home")
					+ "\\Application Data\\Asukaze\\AnxiousJ\\anxious.ini");
			if(makedir){
				try{
					File parent = file.getParentFile();
					if(!parent.exists()){ parent.mkdirs(); }
				}catch(Exception exc){}
			}
			return file.getAbsolutePath();
		}else{
			return System.getProperty("user.home") + File.separator + ".anxiousj";
		}
	}

	private Properties getCurrentProperty(){
		Properties prop = new Properties();
		if(form.getState() == Frame.NORMAL){
			setInteger(prop, "FormLeft", form.getX());
			setInteger(prop, "FormTop", form.getY());
			setInteger(prop, "FormWidth", form.getWidth());
			setInteger(prop, "FormHeight", form.getHeight());
		}
		setInteger(prop, "HintType", form.getHintType());
		setString(prop, "FontFamily", form.getFont().getFamily());
		setInteger(prop, "FontSize", form.getFont().getSize());
		setString(prop, "LookAndFeel", UIManager.getLookAndFeel().getClass().getName());
		return prop;
	}
	
	public void read(){
		try{
			Properties prop = getCurrentProperty();
			FileInputStream fis = new FileInputStream(getConfigureFileName(false)); 
			prop.load(fis);
			fis.close();
			if(form.getState() == Frame.NORMAL){
				form.setBounds(getInteger(prop, "FormLeft"),
						getInteger(prop, "FormTop"),
						getInteger(prop, "FormWidth"),
						getInteger(prop, "FormHeight"));
			}
			form.setHintType(getInteger(prop, "HintType"));
			form.setFont(getString(prop,"FontFamily"), getInteger(prop,"FontSize"));
			UIManager.setLookAndFeel(getString(prop,"LookAndFeel"));
			SwingUtilities.updateComponentTreeUI(form);
		}catch(Exception exc){}
	}
	
	public void write(){
		try{
			Properties prop = getCurrentProperty();
			FileOutputStream fos = new FileOutputStream(getConfigureFileName(true)); 
			prop.save(fos, "AnxiousJ " + Manager.getVersion());
			fos.close();
		}catch(IOException exc){}
	}

	private static String getString(Properties prop, String key){
		return prop.getProperty(key);
	}

	private static int getInteger(Properties prop, String key){
		return Integer.parseInt(prop.getProperty(key));
	}

	private static void setString(Properties prop, String key, String value){
		prop.setProperty(key, value);
	}

	private static void setInteger(Properties prop, String key, int value){
		prop.setProperty(key, Integer.toString(value));
	}
}
